@@ -50,7 +50,7 @@ use JSON;
 use Params::Validate qw( :all );
 use Scalar::Util qw( blessed );
 
-use parent 'App::Dochazka::REST::Resource';
+#use parent 'App::Dochazka::REST::Resource';
 
 
 
@@ -65,11 +65,11 @@ App::Dochazka::REST::Dispatch - path dispatch
 
 =head1 VERSION
 
-Version 0.145
+Version 0.149
 
 =cut
 
-our $VERSION = '0.145';
+our $VERSION = '0.149';
 
 
 
