@@ -36,13 +36,15 @@ use 5.012;
 use strict;
 use warnings FATAL => 'all';
 use App::CELL qw( $CELL $log $meta $site );
+#use App::Dochazka::REST::dbh qw( $dbh );
 use Carp;
 use Data::Dumper;
 use App::Dochazka::REST::Model::Shared qw( load cud );
 use DBI;
 use Params::Validate qw( :all );
 
-use parent 'App::Dochazka::REST::dbh';
+# we get 'spawn', 'reset', and accessors from parent
+use parent 'App::Dochazka::Model::Interval';
 
 
 
@@ -55,11 +57,11 @@ App::Dochazka::REST::Model::Interval - activity intervals data model
 
 =head1 VERSION
 
-Version 0.145
+Version 0.149
 
 =cut
 
-our $VERSION = '0.145';
+our $VERSION = '0.149';
 
 
 
@@ -128,95 +130,23 @@ For basic activity interval workflow, see C<t/010-interval.t>.
 
 
 
-=head1 EXPORTS
-
-This module provides the following exports:
-
-=over 
-
-=back
-
-=cut
-
-use Exporter qw( import );
-our @EXPORT_OK = qw( );
+#=head1 EXPORTS
+#
+#This module provides the following exports:
+#
+#=over 
+#
+#=back
+#
+#=cut
+#
+#use Exporter qw( import );
+#our @EXPORT_OK = qw( );
 
 
 
 =head1 METHODS
 
-=head2 spawn
-
-Constructor. See Employee.pm->spawn for general comments.
-
-=cut
-
-BEGIN {
-    no strict 'refs';
-    *{"spawn"} = App::Dochazka::REST::Model::Shared::make_spawn();
-}
-
-
-
-=head2 reset
-
-Boilerplate.
-
-=cut
-
-BEGIN {
-    no strict 'refs';
-    *{"reset"} = App::Dochazka::REST::Model::Shared::make_reset(
-        'iid', 'eid', 'aid', 'intvl', 'long_desc', 'remark'
-    );
-}
-
-
-
-=head2 Accessor methods
-
-Boilerplate.
-
-=cut
-
-BEGIN {
-    foreach my $subname ( 'iid', 'eid', 'aid', 'intvl', 'long_desc', 'remark' ) {
-        no strict 'refs';
-        *{"$subname"} = App::Dochazka::REST::Model::Shared::make_accessor( $subname );
-    }   
-}
-
-=head3 iid
-
-Accessor method.
-
-
-=head3 eid
-
-Accessor method.
-
-
-=head3 aid
-
-Accessor method.
-
-
-=head3 intvl
-
-Accessor method.
-
-
-=head3 long_desc
-
-Accessor method.
-
-
-=head3 remark
-
-Accessor method.
-
-
-
 =head2 load_by_iid
 
 Boilerplate.
