@@ -36,14 +36,18 @@ use 5.012;
 use strict;
 use warnings FATAL => 'all';
 use App::CELL qw( $CELL $log $meta $site );
+use App::Dochazka::REST::dbh qw( $dbh );
+use App::Dochazka::REST::Model::Shared qw( load cud );
 use Carp;
 use Data::Dumper;
-use App::Dochazka::REST::Model::Shared qw( load cud );
 use DBI;
 use Params::Validate qw( :all );
 use Try::Tiny;
 
-use parent 'App::Dochazka::REST::dbh';
+# we get 'spawn', 'reset', and accessors from parent
+use parent 'App::Dochazka::Model::Privhistory';
+
+
 
 
 =head1 NAME
@@ -55,11 +59,11 @@ App::Dochazka::REST::Model::Privhistory - privilege history functions
 
 =head1 VERSION
 
-Version 0.145
+Version 0.149
 
 =cut
 
-our $VERSION = '0.145';
+our $VERSION = '0.149';
 
 
 
@@ -176,73 +180,6 @@ our @EXPORT_OK = qw( get_privhistory );
 
 =head1 METHODS
 
-=head2 spawn
-
-Constructor. See Employee.pm->spawn for general comments.
-
-=cut
-
-BEGIN {
-    no strict 'refs';
-    *{"spawn"} = App::Dochazka::REST::Model::Shared::make_spawn();
-}
-
-
-
-=head2 reset
-
-Boilerplate.
-
-=cut
-
-BEGIN {
-    no strict 'refs';
-    *{"reset"} = App::Dochazka::REST::Model::Shared::make_reset(
-        'phid', 'eid', 'priv', 'effective', 'remark' 
-    );
-}
-
-
-
-=head2 Accessor methods
-
-Boilerplate.
-
-=cut
-
-BEGIN {
-    foreach my $subname ( 'phid', 'eid', 'priv', 'effective', 'remark') {
-        no strict 'refs';
-        *{"$subname"} = App::Dochazka::REST::Model::Shared::make_accessor( $subname );
-    }   
-}
-
-=head3 phid
-
-Accessor method.
-
-
-=head3 eid
-
-Accessor method.
-
-
-=head3 priv
-
-Accessor method.
-
-
-=head3 effective
-
-Accessor method.
-
-
-=head3 remark
-
-Accessor method.
-
-
-
 =head2 load_by_eid
 
 Supposed to be a class method, but in reality we just don't care what the first
@@ -375,7 +312,6 @@ sub get_privhistory {
     }
     die "AAAAAAAAAAAHHHHH! Engulfed by the abyss" unless $sk and $sql and $tsr;
 
-    my $dbh = __PACKAGE__->SUPER::dbh;
     my $counter = 0;
     $dbh->{RaiseError} = 1;
     try {
